<?php # A page displaying a tutorial describing the use of AutoClickChem.

include('header.php'); # Loads headers and menus ?>

<h2 class="title">AutoClickChem Tutorial</h2>
<div class="story">

<p>This tutorial describes how to use the AutoClickChem program on your own computer.</p>

<p>AutoClickChem generates two lists of PDB files, called reactants1 and reactants2.
The program tries to combine the compounds of the first list with the compounds
of the second list using the reactions of click chemistry. To build these two
lists, use the tags -reactants1 and -reactants2 from the command line. Optionally,
you can also tell AutoClickChem where to save PDB files of the products using the
-output_dir tag. For example,</p>

<tt>python autoclick.py -reactants1 ../azides/myazide.pdb -reactants2 ../alkynes/myalkyne.pdb -output_dir ./output/</tt>

<p>The -reactants1 and -reactants2 tags can also specify directories, in which case
AutoClickChem will add all the PDB files in the specified directory to the respective
list. For example,</p>

<tt>python autoclick.py -reactants1 ../azides/ -reactants2 ../alkynes/ -output_dir ./output/</tt>

<p>The program is not limited to one -reactants1 or -reactants2 tag. For example, the
following is valid:</p>

<tt>python autoclick.py -reactants1 ../azides/myazide.pdb -reactants1 ../azides2/ -reactants2 ../alkynes/myalkyne.pdb -reactants2 ../alkynes2/ -output_dir ./output/</tt>

<p>Some of the AutoClickChem reactions (e.g., alkene to epoxide) require only one type of reactant, not two. To access these reactions, use only the reactants1 tag. For example,</p>

<tt>python autoclick.py -reactants1 ../alkenes/ -output_dir ./my_epoxides/</tt>


<p>Note that, unlike the online version of AutoClickChem, the command-line version only accepts PDB files as input. We recommend using <a href="http://openbabel.org/wiki/Main_Page" target="_blank">OpenBabel</a> to convert your small-molecule models from other formats into the PDB format.</p>

<p>If you would like to limit the number of pairs of compounds that are reacted together,
the max_reactions tag can be used:</p>

<tt>python autoclick.py -reactants1 ../azides/ -reactants2 ../alkynes/ -output_dir ./output/ -max_reactions 10</tt>

<p>The following are special tags that refer to each of the AutoClickChem reactions:</p>

<tt>azide_and_alkyne_to_azole<br/>
epoxide_alcohol_opening<br/>
epoxide_thiol_opening<br/>
chloroformate_and_amine_to_carbamate<br/>
sulfonyl_azide_and_thio_acid<br/>
carboxylate_and_alcohol_to_ester<br/>
carboxylate_and_thiol_to_thioester<br/>
acyl_halide_and_alcohol_to_ester<br/>
acyl_halide_and_thiol_to_thioester<br/>
ester_and_alcohol_to_ester<br/>
ester_and_thiol_to_thioester<br/>
acid_anhydride_and_alcohol_to_ester<br/>
acid_anhydride_and_thiol_to_thioester<br/>
carboxylate_and_amine_to_amide<br/>
acyl_halide_and_amine_to_amide<br/>
ester_and_amine_to_amide<br/>
acid_anhydride_and_amine_to_amide<br/>
isocyanate_and_amine_to_urea<br/>
isothiocyanate_and_amine_to_thiourea<br/>
isocyanate_and_alcohol_to_carbamate<br/>
isothiocyanate_and_alcohol_to_carbamothioate<br/>
isocyanate_and_thiol_to_carbamothioate<br/>
isothiocyanate_and_thiol_to_carbamodithioate<br/>
alkene_to_epoxide<br/>
halide_to_cyanide<br/>
alcohol_to_cyanide<br/>
carboxylate_to_cyanide<br/>
acyl_halide_to_cyanide<br/>
acid_anhydride_to_cyanide<br/>
halide_to_azide<br/>
alcohol_to_azide<br/>
carboxylate_to_azide<br/>
acyl_halide_to_azide<br/>
acid_anhydride_to_azide<br/>
amine_to_azide<br/>
amine_to_isocyanate<br/>
amine_to_isothiocyanate<br/>
azide_to_amine</tt>

<p>By default, AutoClickChem performs all reactions possible. Specific reactions can be turned
on or off by by placing a + or -, respectively, before the appropriate tag. For example,
if you want AutoClickChem to avoid opening epoxides, the following tags can be used:</p>

<tt>python autoclick.py -reactants1 ../azides/ -reactants2 ../alkynes/ -output_dir ./output/ -epoxide_alcohol_opening -epoxide_thiol_opening</tt>

<p>The tag "all_reactions" is also valid. If you'd like to perform only the
azide_and_alkyne_to_azole reaction, for example, the following tags can be used:</p>

<tt>python autoclick.py -reactants1 ../azides/ -reactants2 ../alkynes/ -output_dir ./output/ -all_reactions +azide_and_alkyne_to_azole</tt>

<p>I hope you enjoy using AutoClickChem!</p>

</div>

<?php include('footer.php'); # The footer and sidebar. ?>
